@@ -39,14 +39,14 @@ class Storage(driver.Base):
         
         return object_instance.generate_url("GET")
     
-#    def get_json(self, path):
-#        logger.info("get_json path:%s" % path)
-#        try:
-#            return json.loads(self.get_unicode(path))
-#        except Exception as e:
-#            logger.error("get_json error:%s" % e)
-#            return []
-#        
+    def get_json(self, path):
+        logger.info("get_json path:%s" % path)
+        try:
+            return json.loads(self.get_unicode(path))
+        except Exception as e:
+            logger.error("get_json error:%s" % e)
+            return []
+        
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
